@@ -4,6 +4,12 @@ use 5.006;
 use strict;
 use warnings;
 
+require Exporter;
+require DynaLoader;
+our @ISA = qw(Exporter DynaLoader);
+
+our $VERSION = '0.20';
+
 # use all files under Ogre/ - probably not a good idea
 use Ogre::Camera;
 use Ogre::ColourValue;
@@ -11,22 +17,25 @@ use Ogre::ConfigFile;
 use Ogre::Degree;
 use Ogre::Entity;
 use Ogre::Light;
-use Ogre::Node;
+use Ogre::LogManager;
+use Ogre::MeshManager;
+use Ogre::MeshPtr;
 use Ogre::MovableObject;
+use Ogre::Node;
+use Ogre::OverlayManager;
+use Ogre::Plane;
 use Ogre::Radian;
+use Ogre::RenderTarget;
 use Ogre::RenderWindow;
+use Ogre::ResourceGroupManager;
 use Ogre::Root;
 use Ogre::SceneManager;
 use Ogre::SceneNode;
-use Ogre::ResourceGroupManager;
 use Ogre::TextureManager;
+use Ogre::Vector3;
 use Ogre::Viewport;
+use Ogre::WindowEventUtilities;
 
-require Exporter;
-require DynaLoader;
-our @ISA = qw(Exporter DynaLoader);
-
-our $VERSION = '0.1';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
